# -*- coding: utf8 -*-

import sys
import argparse
from .sms import FreeMobileSMS


def main():
    parser = argparse.ArgumentParser(description="Free Mobile SMS Service for sending SMS")
    parser.add_argument("message", help="Your message")
    parser.add_argument("--config", help="Path for config file")
    parser.add_argument("-v", "--verbose", help="Verbose mode", action="store_true")
    args = parser.parse_args()
    sms = FreeMobileSMS(args.config)
    if not sys.stdin.isatty():
        msg = sys.stdin.read()
    else:
        try:
            msg = args.message.decode(sys.stdin.encoding)
        except:
            msg = args.message
    status, value = sms.send(msg)
    if args.verbose:
        print(str(status) + " " + value)



from setuptools import setup

try:
   import pypandoc
   description = pypandoc.convert("README.md", "rst")
except:
   description = "Library to use Free Mobile SMS service with Python"

try:
    with open(".version", "r") as file:
        version = file.read()
except:
    version = "0.0.0"

setup(
    name="freemobilesms",
    description="Free Mobile SMS Service",
    long_description=description,
    version=version,
    url="https://github.com/hug33k/FreeMobileSMS",
    download_url="https://github.com/hug33k/FreeMobileSMS/archive/{version}.tar.gz".format(version=version),
    author="Hugo SCHOCH",
    author_email="schoch.hugo@gmail.com",
    license="Apache2",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 2"
    ],
    keywords=[
        "free mobile",
        "freemobile",
        "free",
        "sms"
    ],
    packages=[
        "freemobilesms"
    ],
    install_requires=[
        "urllib3",
        "requests"
    ],
    entry_points={
        "console_scripts": [
            "sms=freemobilesms.cli:main"
        ]
    }
)


# -*- coding: utf8 -*-

import json
import os
import requests
try:
    from urllib.parse import quote
except ImportError:
    from urllib import quote


class FreeMobileSMS(object):
    def __init__(self, config=None):
        self._URL = "https://smsapi.free-mobile.fr/sendmsg?user={0}&pass={1}&msg={2}"
        self._codes = {
            200: "Message send",
            400: "Missing parameter",
            402: "Too much messages send",
            403: "Service not enable",
            500: "Server not available"
        }
        if config:
            with open(config, "r") as conf_file:
                try:
                    data_file = json.load(conf_file)
                    self._login = data_file["login"]
                    self._token = data_file["token"]
                except:
                    raise Exception("Error with file " + config + "\n")
        else:
            if "SMS_LOGIN" not in os.environ:
                raise Exception("Missing SMS_LOGIN")
            if "SMS_TOKEN" not in os.environ:
                raise Exception("Missing SMS_TOKEN")
            self._login = os.environ["SMS_LOGIN"]
            self._token = os.environ["SMS_TOKEN"]

    def _make_route(self, message):
        return self._URL.format(self._login, self._token, quote(message.encode('utf-8')))

    def _check_code(self, code):
        if code in self._codes:
            return code, self._codes[code]
        else:
            return code, "Error message not found"

    def send(self, message):
        route = self._make_route(message)
        res = requests.get(route)
        return self._check_code(int(res.status_code))
